@@ -446,9 +446,57 @@ def midpoint(p, a, b):
     return a + (b - a) * p
 
 
+def interpolate_rotation_matrices(p, r1, r2):
+    """Interpolate between two rotation matrices.
+
+    Performs spherical linear interpolation (SLERP) between two rotation
+    matrices. This gives a smooth rotation path from r1 to r2.
+
+    Parameters
+    ----------
+    p : float
+        Interpolation parameter in [0, 1]. When p=0, returns r1.
+        When p=1, returns r2. When p=0.5, returns the midpoint rotation.
+    r1 : numpy.ndarray
+        Starting 3x3 rotation matrix
+    r2 : numpy.ndarray
+        Ending 3x3 rotation matrix
+
+    Returns
+    -------
+    r : numpy.ndarray
+        Interpolated 3x3 rotation matrix
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from skrobot.coordinates.math import interpolate_rotation_matrices
+    >>> interpolate_rotation_matrices(0.5,
+            np.eye(3),
+            np.array([[0, 0, 1], [0, 1, 0], [-1, 0, 0]]))
+    array([[ 0.70710678,  0.        ,  0.70710678],
+           [ 0.        ,  1.        ,  0.        ],
+           [-0.70710678,  0.        ,  0.70710678]])
+    >>> from skrobot.coordinates.math import matrix2ypr
+    >>> np.rad2deg(matrix2ypr(interpolate_rotation_matrices(0.5,
+                   np.eye(3),
+                   np.array([[0, 0, 1], [0, 1, 0], [-1, 0, 0]]))))
+    array([ 0., 45.,  0.])
+    """
+    r1 = _check_valid_rotation(r1)
+    r2 = _check_valid_rotation(r2)
+    r = np.matmul(r1.T, r2)
+    omega = rotation_matrix_to_axis_angle_vector(r)
+    r = axis_angle_vector_to_rotation_matrix(omega, p)
+    return np.matmul(r1, r)
+
+
 def midrot(p, r1, r2):
     """Returns mid (or p) rotation matrix of given two matrix r1 and r2.
 
+    .. deprecated::
+        This function is deprecated. Use `interpolate_rotation_matrices` instead.
+
     Parameters
     ----------
     p : float
@@ -479,12 +527,12 @@ def midrot(p, r1, r2):
                    np.array([[0, 0, 1], [0, 1, 0], [-1, 0, 0]])))[0])
     array([ 0., 45.,  0.])
     """
-    r1 = _check_valid_rotation(r1)
-    r2 = _check_valid_rotation(r2)
-    r = np.matmul(r1.T, r2)
-    omega = matrix_log(r)
-    r = matrix_exponent(omega, p)
-    return np.matmul(r1, r)
+    warnings.warn(
+        'Function `midrot` is deprecated. '
+        'Please use `interpolate_rotation_matrices` instead',
+        DeprecationWarning,
+        stacklevel=2)
+    return interpolate_rotation_matrices(p, r1, r2)
 
 
 def transform(m, v):
@@ -1050,9 +1098,49 @@ def quaternion2matrix(q, normalize=False):
     return m
 
 
+def rotation_matrix_to_axis_angle_vector(m):
+    """Convert rotation matrix to axis-angle representation as a vector.
+
+    The magnitude of the returned vector represents the rotation angle,
+    and its direction represents the rotation axis.
+
+    Parameters
+    ----------
+    m : list or numpy.ndarray
+        3x3 rotation matrix
+
+    Returns
+    -------
+    axis_angle_vector : numpy.ndarray
+        Axis-angle representation as a vector of shape (3,).
+        The vector's magnitude is the rotation angle in radians [-pi, pi],
+        and its direction is the rotation axis.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from skrobot.coordinates.math import rotation_matrix_to_axis_angle_vector
+    >>> rotation_matrix_to_axis_angle_vector(np.eye(3))
+    array([0., 0., 0.])
+    """
+    # calc logarithm of quaternion
+    q = matrix2quaternion(m)
+    q_w = q[0]
+    q_xyz = q[1:]
+    theta = 2.0 * np.arctan(np.linalg.norm(q_xyz) / q_w)
+    if theta > np.pi:
+        theta = theta - 2.0 * np.pi
+    elif theta < - np.pi:
+        theta = theta + 2.0 * np.pi
+    return theta * normalize_vector(q_xyz)
+
+
 def matrix_log(m):
     """Returns matrix log of given rotation matrix, it returns [-pi, pi]
 
+    .. deprecated::
+        This function is deprecated. Use `rotation_matrix_to_axis_angle_vector` instead.
+
     Parameters
     ----------
     m : list or numpy.ndarray
@@ -1070,21 +1158,61 @@ def matrix_log(m):
     >>> matrix_log(np.eye(3))
     array([0., 0., 0.])
     """
-    # calc logarithm of quaternion
-    q = matrix2quaternion(m)
-    q_w = q[0]
-    q_xyz = q[1:]
-    theta = 2.0 * np.arctan(np.linalg.norm(q_xyz) / q_w)
-    if theta > np.pi:
-        theta = theta - 2.0 * np.pi
-    elif theta < - np.pi:
-        theta = theta + 2.0 * np.pi
-    return theta * normalize_vector(q_xyz)
+    warnings.warn(
+        'Function `matrix_log` is deprecated. '
+        'Please use `rotation_matrix_to_axis_angle_vector` instead',
+        DeprecationWarning,
+        stacklevel=2)
+    return rotation_matrix_to_axis_angle_vector(m)
+
+
+def axis_angle_vector_to_rotation_matrix(omega, p=1.0):
+    """Convert axis-angle vector representation to rotation matrix.
+
+    Converts an axis-angle representation (where the vector direction
+    is the rotation axis and magnitude is the rotation angle) to a
+    rotation matrix using Rodrigues' formula.
+
+    Parameters
+    ----------
+    omega : list or numpy.ndarray
+        Axis-angle vector of shape (3,). The direction represents
+        the rotation axis and the magnitude represents the rotation
+        angle in radians.
+    p : float, optional
+        Interpolation parameter (default: 1.0). When p=1.0, returns
+        the full rotation. When 0<p<1, returns partial rotation.
+
+    Returns
+    -------
+    rot : numpy.ndarray
+        3x3 rotation matrix
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from skrobot.coordinates.math import axis_angle_vector_to_rotation_matrix
+    >>> axis_angle_vector_to_rotation_matrix([1, 1, 1])
+    array([[ 0.22629564, -0.18300792,  0.95671228],
+           [ 0.95671228,  0.22629564, -0.18300792],
+           [-0.18300792,  0.95671228,  0.22629564]])
+    >>> axis_angle_vector_to_rotation_matrix([1, 0, 0])
+    array([[ 1.        ,  0.        ,  0.        ],
+           [ 0.        ,  0.54030231, -0.84147098],
+           [ 0.        ,  0.84147098,  0.54030231]])
+    """
+    w = np.linalg.norm(omega)
+    amat = skew_symmetric_matrix(normalize_vector(omega))
+    return np.eye(3) + np.sin(w * p) * amat + \
+        (1.0 - np.cos(w * p)) * np.matmul(amat, amat)
 
 
 def matrix_exponent(omega, p=1.0):
     """Returns exponent of given omega.
 
+    .. deprecated::
+        This function is deprecated. Use `axis_angle_vector_to_rotation_matrix` instead.
+
     This function is similar to cv2.Rodrigues.
     Convert rvec (which is log quaternion) to rotation matrix.
 
@@ -1111,16 +1239,83 @@ def matrix_exponent(omega, p=1.0):
            [ 0.        ,  0.54030231, -0.84147098],
            [ 0.        ,  0.84147098,  0.54030231]])
     """
-    w = np.linalg.norm(omega)
-    amat = outer_product_matrix(normalize_vector(omega))
-    return np.eye(3) + np.sin(w * p) * amat + \
-        (1.0 - np.cos(w * p)) * np.matmul(amat, amat)
+    warnings.warn(
+        'Function `matrix_exponent` is deprecated. '
+        'Please use `axis_angle_vector_to_rotation_matrix` instead',
+        DeprecationWarning,
+        stacklevel=2)
+    return axis_angle_vector_to_rotation_matrix(omega, p)
+
+
+def skew_symmetric_matrix(v):
+    """Returns skew-symmetric matrix of given vector v.
+
+    This function creates a skew-symmetric matrix (also known as an antisymmetric matrix)
+    that represents the cross product operation as matrix multiplication.
+    For any vectors a and v, the cross product v x a is equivalent to the matrix-vector
+    product of the skew-symmetric matrix of v and the vector a.
+
+    v × a = skew_symmetric_matrix(v) @ a
+
+    .. math::
+        \\left(
+            \\begin{array}{ccc}
+                0 & -v_2 & v_1 \\\\
+                v_2 & 0 & -v_0 \\\\
+                -v_1 & v_0 & 0
+            \\end{array}
+        \\right)
+
+    Parameters
+    ----------
+    v : numpy.ndarray or list
+        3D vector [v0, v1, v2]
+
+    Returns
+    -------
+    matrix : numpy.ndarray
+        3x3 skew-symmetric matrix.
+
+    Examples
+    --------
+    >>> from skrobot.coordinates.math import skew_symmetric_matrix
+    >>> skew_symmetric_matrix([1, 2, 3])
+    array([[ 0, -3,  2],
+           [ 3,  0, -1],
+           [-2,  1,  0]])
+
+    >>> # Verify cross product equivalence: v x a = [v]x @ a
+    >>> import numpy as np
+    >>> v = np.array([0, 1, 0])  # vector j
+    >>> a = np.array([1, 0, 0])  # vector i
+    >>>
+    >>> # Expected result of v x a (j x i) is -k = [0, 0, -1]
+    >>> cross_result = np.cross(v, a)
+    >>> matrix_result = skew_symmetric_matrix(v) @ a
+    >>>
+    >>> print(f"np.cross(v, a) = {cross_result}")
+    np.cross(v, a) = [ 0  0 -1]
+    >>> print(f"skew_symmetric_matrix(v) @ a = {matrix_result}")
+    skew_symmetric_matrix(v) @ a = [ 0.  0. -1.]
+    >>>
+    >>> np.allclose(cross_result, matrix_result)
+    True
+    """
+    # Ensure v is a numpy array for consistent indexing
+    v = np.asarray(v)
+    return np.array([[0, -v[2], v[1]],
+                     [v[2], 0, -v[0]],
+                     [-v[1], v[0], 0]])
 
 
 def outer_product_matrix(v):
-    """Returns outer product matrix of given v.
+    """Returns skew-symmetric matrix of given v.
 
-    Returns following outer product matrix.
+    .. deprecated::
+        This function name is misleading. It actually returns a skew-symmetric matrix,
+        not an outer product matrix. Use `skew_symmetric_matrix` instead.
+
+    Returns following skew-symmetric matrix (incorrectly called "outer product matrix").
 
     .. math::
         \\left(
@@ -1139,7 +1334,7 @@ def outer_product_matrix(v):
     Returns
     -------
     matrix : numpy.ndarray
-        3x3 rotation matrix.
+        3x3 skew-symmetric matrix (NOT outer product matrix).
 
     Examples
     --------
@@ -1149,9 +1344,13 @@ def outer_product_matrix(v):
            [ 3,  0, -1],
            [-2,  1,  0]])
     """
-    return np.array([[0, -v[2], v[1]],
-                     [v[2], 0, -v[0]],
-                     [-v[1], v[0], 0]])
+    warnings.warn(
+        'Function `outer_product_matrix` is deprecated and incorrectly named. '
+        'It actually returns a skew-symmetric matrix, not an outer product matrix. '
+        'Please use `skew_symmetric_matrix` instead',
+        DeprecationWarning,
+        stacklevel=2)
+    return skew_symmetric_matrix(v)
 
 
 def cross_product(a, b):
@@ -1342,6 +1541,77 @@ def rotation_matrix_from_axis(
     return np.vstack([e1, e2, e3])[np.argsort(indices)].T
 
 
+def rotation_matrix_z_to_axis(axis):
+    """Create rotation matrix that aligns Z-axis to target axis direction.
+
+    This is a convenience wrapper around rotation_matrix_from_axis that
+    automatically selects an appropriate second axis (X or Y) to fully determine
+    the rotation matrix. The resulting rotation matrix will transform the Z-axis
+    [0, 0, 1] to point in the target axis direction.
+
+    Difference from rotation_matrix_from_axis:
+    - rotation_matrix_from_axis: Requires explicit specification of both axes
+    - rotation_matrix_z_to_axis: Only requires target axis, automatically selects second axis
+
+    This function is particularly useful for URDF cylinder primitives, which are
+    defined with their central axis along the Z-axis.
+
+    Parameters
+    ----------
+    axis : numpy.ndarray or list or tuple
+        Target axis direction for Z-axis alignment (will be normalized).
+        The Z-axis [0, 0, 1] of the resulting rotation matrix will be aligned
+        with this direction.
+
+    Returns
+    -------
+    rotation : numpy.ndarray
+        3x3 rotation matrix R such that R @ [0, 0, 1] is parallel to axis.
+
+    Examples
+    --------
+    >>> from skrobot.coordinates.math import rotation_matrix_z_to_axis
+    >>> import numpy as np
+    >>> # Align Z-axis with X-axis [1, 0, 0]
+    >>> R = rotation_matrix_z_to_axis([1, 0, 0])
+    >>> np.allclose(R @ [0, 0, 1], [1, 0, 0])
+    True
+    >>> # Align Z-axis with diagonal direction [0, 1, 1]
+    >>> R = rotation_matrix_z_to_axis([0, 1, 1])
+    >>> np.allclose(R @ [0, 0, 1], [0, 1/np.sqrt(2), 1/np.sqrt(2)])
+    True
+
+    See Also
+    --------
+    rotation_matrix_from_axis : Create rotation matrix from two explicit axes
+
+    Notes
+    -----
+    The second axis is automatically chosen to avoid gimbal lock:
+    - If the target axis is close to the X-axis, Y-axis is used as a hint
+    - Otherwise, X-axis is used as a hint
+
+    This ensures a stable rotation even when the target axis is aligned with
+    or close to a cardinal axis.
+    """
+    axis = np.asarray(axis, dtype=float)
+    axis = axis / np.linalg.norm(axis)
+
+    # Select second axis hint to avoid gimbal lock
+    # If axis is close to X-axis, use Y-axis as hint; otherwise use X-axis
+    if abs(axis[0]) < 0.9:
+        second_axis = np.array([1, 0, 0])  # Use X-axis as hint
+    else:
+        second_axis = np.array([0, 1, 0])  # Use Y-axis as hint
+
+    # Create rotation matrix with Z-axis aligned to target and X-axis hint
+    return rotation_matrix_from_axis(
+        first_axis=axis,
+        second_axis=second_axis,
+        axes='zx'
+    )
+
+
 def rodrigues(axis, theta=None, skip_normalization=False):
     """Rodrigues formula.
 
