@@ -83,6 +83,20 @@ def kuka_urdfpath():
     return osp.join(data_dir, 'kuka_description', 'kuka.urdf')
 
 
+def nextage_urdfpath():
+    path = osp.join(get_cache_dir(), 'nextage_description', 'urdf', 'NextageOpen.urdf')
+    if osp.exists(path):
+        return path
+    _download(
+        url='https://github.com/iory/scikit-robot-models/raw/refs/heads/master/nextage_description.tar.gz',  # NOQA
+        path=osp.join(get_cache_dir(), 'nextage_description.tar.gz'),
+        md5='9805ac9cd97b67056dde31aa88762ec7',
+        postprocess='extractall',
+        quiet=True,
+    )
+    return path
+
+
 def panda_urdfpath():
     path = osp.join(get_cache_dir(),
                     'franka_description', 'panda.urdf')
