@@ -63,7 +63,8 @@ def calc_target_joint_dimension(joint_list):
     """
     n = 0
     for j in joint_list:
-        n += j.joint_dof
+        if j is not None:
+            n += j.joint_dof
     return n
 
 
@@ -170,6 +171,52 @@ class Joint(object):
     def type(self):
         raise NotImplementedError('Joint type must be defined')
 
+    @property
+    def joint_type(self):
+        """Alias for type property for better clarity.
+
+        Using joint_type makes it more explicit that this is a joint property,
+        reducing confusion with other 'type' attributes in the codebase.
+
+        Returns
+        -------
+        str
+            Joint type ('revolute', 'continuous', 'prismatic', 'fixed', etc.)
+        """
+        return self.type
+
+    @property
+    def min_joint_angle(self):
+        """Alias for min_angle property for better clarity.
+
+        Returns
+        -------
+        float
+            Minimum joint angle
+        """
+        return self.min_angle
+
+    @min_joint_angle.setter
+    def min_joint_angle(self, value):
+        """Setter for min_joint_angle (updates min_angle)."""
+        self.min_angle = value
+
+    @property
+    def max_joint_angle(self):
+        """Alias for max_angle property for better clarity.
+
+        Returns
+        -------
+        float
+            Maximum joint angle
+        """
+        return self.max_angle
+
+    @max_joint_angle.setter
+    def max_joint_angle(self, value):
+        """Setter for max_joint_angle (updates max_angle)."""
+        self.max_angle = value
+
     @property
     def joint_dof(self):
         raise NotImplementedError
@@ -199,6 +246,48 @@ class Joint(object):
         mimic_joint_hook = _MimicJointHook(self, joint, multiplier, offset)
         self.register_hook(mimic_joint_hook)
 
+    @property
+    def world_axis(self):
+        """Return joint axis in world coordinate system.
+
+        For rotational and linear joints, this converts the local axis
+        to world coordinates using the parent link's world transformation
+        and the joint's default coordinates (initial pose).
+
+        This follows the same calculation as the non-batch Jacobian:
+        world_default_coords = parent_link.worldcoords().transform(default_coords)
+        world_axis = world_default_coords.rotate_vector(axis)
+
+        Returns
+        -------
+        axis : numpy.ndarray
+            Joint axis in world coordinate system.
+        """
+        if not hasattr(self, 'axis'):
+            return np.array([0, 0, 1])
+
+        if self.parent_link is not None:
+            return self.parent_link.copy_worldcoords().transform(
+                self.default_coords).rotate_vector(self.axis)
+
+        return self.default_coords.rotate_vector(self.axis)
+
+    @property
+    def world_position(self):
+        """Return joint position in world coordinate system.
+
+        The joint position is defined as the world position of the parent link.
+
+        Returns
+        -------
+        position : numpy.ndarray
+            Joint position in world coordinate system.
+        """
+        if self.parent_link is not None:
+            return self.parent_link.copy_worldcoords().transform(
+                self.default_coords).worldpos()
+        return self.default_coords.worldpos()
+
 
 class RotationalJoint(Joint):
 
@@ -235,6 +324,22 @@ class RotationalJoint(Joint):
             return 'continuous'
         return 'revolute'
 
+    @property
+    def joint_axis(self):
+        """Alias for axis property for better clarity.
+
+        Returns
+        -------
+        numpy.ndarray
+            Joint rotation axis (normalized 3D vector)
+        """
+        return self.axis
+
+    @joint_axis.setter
+    def joint_axis(self, value):
+        """Setter for joint_axis (updates axis)."""
+        self.axis = normalize_vector(convert_to_axis_vector(value))
+
     def joint_angle(self, v=None, relative=None, enable_hook=True):
         """Return joint angle.
 
@@ -404,6 +509,22 @@ class LinearJoint(Joint):
     def type(self):
         return 'prismatic'
 
+    @property
+    def joint_axis(self):
+        """Alias for axis property for better clarity.
+
+        Returns
+        -------
+        numpy.ndarray
+            Joint translation axis (normalized 3D vector)
+        """
+        return self.axis
+
+    @joint_axis.setter
+    def joint_axis(self, value):
+        """Setter for joint_axis (updates axis)."""
+        self.axis = normalize_vector(convert_to_axis_vector(value))
+
     def joint_angle(self, v=None, relative=None, enable_hook=True):
         """Return this joint's linear translation (joint angle).
 
